analphipy.PhiGeneric
====================

.. currentmodule:: analphipy

.. autoclass:: PhiGeneric

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~PhiGeneric.__init__
      ~PhiGeneric.asdict
      ~PhiGeneric.assign
      ~PhiGeneric.assign_min_numeric
      ~PhiGeneric.cut
      ~PhiGeneric.dphidr
      ~PhiGeneric.lfs
      ~PhiGeneric.minimize
      ~PhiGeneric.new_like
      ~PhiGeneric.phi
      ~PhiGeneric.to_measures
      ~PhiGeneric.to_nf
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree:
   
      ~PhiGeneric.phi_func
      ~PhiGeneric.dphidr_func
      ~PhiGeneric.phi_min
      ~PhiGeneric.r_min
      ~PhiGeneric.segments
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~PhiGeneric.__repr__
   
   